@@ -6,17 +6,17 @@ referenced
 from typing import List
 
 import pytest
-
 from shade import ShadeLocal
 from shade.v1.models import Job, AssetModel, JobState
 from tests.helpers import wait_for_jobs
+import platform
 
 
-@pytest.mark.parametrize('demo_file_name', [
+@pytest.mark.parametrize('demo_file_names', [[
     'video/coverr-berlin-underground-train-7268-original.mp4',
     # TODO doesn't seem like braw is working
     'video/braw-r3d/A002_C305_0523UB_001.R3D',
-    'video/Filmplusgear-skiers-Samnaun-2019-dci-Q5.braw',
+    'video/Filmplusgear-skiers-Samnaun-2019-dci-Q5.braw' if platform.system() != 'Linux' else None,
     'image/exr-hdr-weird/bw_full.exr',
     'image/exr-hdr-weird/bw_half.exr',
     'image/exr-hdr-weird/rgb_full.exr',
@@ -33,45 +33,45 @@ from tests.helpers import wait_for_jobs
     'image/photo-3.jpg',
     'image/schema.webp',
 
+    # exr's are failing on my machine -matias
     'image/exr-hdr-weird/farm_sunset_1k.hdr',
     'image/exr-hdr-weird/limpopo_golf_course_1k.hdr',
     'image/exr-hdr-weird/sample_640426.hdr'
-])
-def test_visual_assets(
-        demo_asset: AssetModel,
+]])
+def test_visual_assets_batched(
+        demo_assets: List[AssetModel],
         backend: ShadeLocal,
 ):
     # wait for jobs to run
-    asset = wait_for_jobs(backend, [
+    for asset in wait_for_jobs(backend, [
         Job.METADATA, Job.CORE, Job.PREVIEWS, Job.COLOR_PALETTE
-    ], [demo_asset])[0]
-
-    assert asset.signature
-    assert asset.ai_indexed
-    assert asset.palette
-    assert asset.preview_images
-    assert asset.tags
+    ], demo_assets):
+        assert asset.signature
+        assert asset.ai_indexed
+        assert asset.palette
+        assert asset.preview_images
+        assert asset.tags
 
 
-@pytest.mark.parametrize('demo_file_name', [
-    'audio/Cymatics - Buildup Drums 19 - 140 BPM.wav',
-    'audio/Cymatics - Buildup Drums 20 - 140 BPM.wav',
-    'audio/Cymatics - Buildup Drums 24 - 150 BPM.wav',
-    'audio/Snap Sound Effect [ HD ].mp3',
-    'audio/item_purchase.ogg',
-])
-def test_audio_assets(
-        demo_asset: AssetModel,
-        backend: ShadeLocal,
-):
-    asset = wait_for_jobs(backend, [
-        Job.METADATA,
-        Job.AUDIO
-    ], [demo_asset])[0]
-
-    # assert asset.size_bytes
-    assert asset.tags
-    assert asset.ai_indexed
+# @pytest.mark.parametrize('demo_file_name', [
+#     'audio/Cymatics - Buildup Drums 19 - 140 BPM.wav',
+#     'audio/Cymatics - Buildup Drums 20 - 140 BPM.wav',
+#     'audio/Cymatics - Buildup Drums 24 - 150 BPM.wav',
+#     'audio/Snap Sound Effect [ HD ].mp3',
+#     'audio/item_purchase.ogg',
+# ])
+# def test_audio_assets(
+#         demo_asset: AssetModel,
+#         backend: ShadeLocal,
+# ):
+#     asset = wait_for_jobs(backend, [
+#         Job.METADATA,
+#         Job.AUDIO
+#     ], [demo_asset])[0]
+#
+#     # assert asset.size_bytes
+#     assert asset.tags
+#     assert asset.ai_indexed
 
 
 @pytest.mark.parametrize('demo_file_name', [
@@ -92,9 +92,9 @@ def test_text_assets(
 
 
 @pytest.mark.parametrize('demo_file_names', [
-    ([f'images/freeman{i}.jpg' for i in range(1, 8)]),
+    [f'images/freeman{i}.jpg' for i in range(1, 8)],
 ])
-def test_facial_recognition(
+def test_facial_recognition_batched(
         demo_assets: List[AssetModel],
         backend: ShadeLocal,
 ):
@@ -102,7 +102,7 @@ def test_facial_recognition(
         Job.METADATA,
         Job.FACIAL_RECOGNITION,
         Job.CORE
-    ], [demo_assets], timeout=120)
+    ], demo_assets)
 
     # TODO check for individuals
 
